@@ -33,6 +33,8 @@ int disp_h = 15, disp_w = 60;
 extern int curitem;
 extern WINDOW *bottom;
 
+const char* BOOL_YN[] = { NO, YES };
+
 int
 action_list_add_pw()
 {
@@ -181,7 +183,9 @@ action_edit_options()
 		{"GnuPG Path:\t", options->gpg_path, STRING_LONG, STRING},
 		{"GnuPG ID:\t", options->gpg_id, STRING_LONG, STRING},
 		{"Password File:\t", options->password_file, STRING_LONG, STRING},
-		{"Passphrase Timeout(in minutes):\t", &options->passphrase_timeout, STRING_SHORT, INT}
+		{"Passphrase Timeout(in minutes):\t", &options->passphrase_timeout, STRING_SHORT, INT},
+		{"Sign Password Database:\t", &options->sign_db, 1, BOOLEAN},
+		{"Read Only:\t", &options->readonly, 1, BOOLEAN}
 	};
 
 	action_input_dialog(fields, (sizeof(fields)/sizeof(InputField)), "Edit Preferences");
@@ -193,7 +197,7 @@ int
 action_input_dialog_draw_items(WINDOW* dialog_win, InputField *fields, 
 		int num_fields, char *title, char *msg)
 {
-	int i, h = 0;
+	int i, bv, h = 0;
 
 	wclear(dialog_win);
 	
@@ -215,7 +219,11 @@ action_input_dialog_draw_items(WINDOW* dialog_win, InputField *fields,
 				"%d - %s %s", (i+1), fields[i].name, (char*)fields[i].value);
 		} else if(fields[i].type == INT){
 			mvwprintw(dialog_win, h, 3,
-				"%d - %s %d", (i+1), fields[i].name, *((int*)fields[i].value) );
+				"%d - %s %d", (i+1), fields[i].name, *((int*)fields[i].value));
+		} else if(fields[i].type == BOOLEAN){
+			bv = *(int*)fields[i].value;
+			mvwprintw(dialog_win, h, 3,
+				"%d - %s %s", (i+1), fields[i].name, (char*)BOOL_YN[bv]);
 		} else if(fields[i].type == INFORMATION){
 			mvwprintw(dialog_win, h, 3,
 				"%d - %s", (i+1), fields[i].name);
@@ -273,6 +281,8 @@ action_input_dialog(InputField *fields, int num_fields, char *title)
 				} else if(fields[i].type == STRING){
 					fields[i].value = (char*)ui_statusline_ask_str(fields[i].name, 
 								(char*)fields[i].value, fields[i].max_length);
+				} else if(fields[i].type == BOOLEAN){
+					ui_statusline_ask_bool(fields[i].name, (int*)fields[i].value);
 				} else if(fields[i].type == INT){
 					ui_statusline_ask_num(fields[i].name, (int*)fields[i].value);
 				} else if(fields[i].type == INFORMATION){
