@@ -34,7 +34,7 @@ char* gnupg_get_filename(char*, char);
 const char* gnupg_get_passphrase();
 
 int gnupg_read(char*, xmlDocPtr*);
-int gnupg_write(xmlDocPtr, char*, char*);
-int gnupg_write_many(xmlDocPtr, char**, int, char*);
+int gnupg_write(xmlDocPtr, char*, char*, char*);
+int gnupg_write_many(xmlDocPtr, char*, char**, int, char*);
 
 #endif
